// Copyright 2017-2019 David Robillard <d@drobilla.net>
// SPDX-License-Identifier: ISC

#include <lilv/lilvmm.hpp>

int
main()
{
  const Lilv::World world{};

  return 0;
}
